Layouts
=======
.. currentmodule:: graspologic.layouts

NodePosition
------------
.. autoclass:: NodePosition

Automatic Graph Layout
----------------------
.. autofunction:: layout_tsne
.. autofunction:: layout_umap

Colors
------
.. autofunction:: categorical_colors
.. autofunction:: sequential_colors

Rendering
---------
.. autofunction:: save_graph
.. autofunction:: show_graph
